(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     97195,       2458]*)
(*NotebookOutlinePosition[    101452,       2594]*)
(*  CellTagsIndexPosition[    101283,       2584]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Converting MathCAD documents", "Title"],

Cell[CellGroupData[{

Cell["Operating the converter", "Section",
  CellTags->"sc1"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Beta Version",
  FontColor->RGBColor[1, 0, 0]]], "Subsubsection",
  CellTags->"sc1"],

Cell["Load the package...", "Text",
  CellTags->"sc1"],

Cell[BoxData[
    \(<< MCRead`\)], "Input",
  CellTags->"sc1"],

Cell[TextData[{
  "Use the command ",
  StyleBox["MCRead[ path ]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with the path of the MathCAD file. EG."
}], "Text",
  CellTags->"sc1"],

Cell[BoxData[
    \(MCRead["\<C://Files//Example.mcd\>"]\)], "Input",
  CellTags->"sc1"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will read and convert the document before opening it as a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebook. This notebook can be edited and saved and in some cases \
evaluated in the same way as normal ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebooks. \nYou can also use the command ",
  StyleBox["MCRead[ path, DisplayForm->TraditionalForm]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " eg"
}], "Text",
  CellTags->"sc1"],

Cell[BoxData[
    \(MCRead["\<C://Files//Example.mcd\>", DisplayForm -> TraditionalForm]
      \)], "Input",
  CellTags->"sc1"],

Cell[TextData[{
  "This will open the file and convert all maths cells into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " TraditionalForm, using some additional formatting rules to make the \
document look more like the original document.",
  StyleBox[
  "\nIf you have opened the file in TraditionalForm and intend to edit the \
notebook then it is highly recommended that you convert all the cells into \
StandardForm first.",
    FontWeight->"Bold"],
  " \n(Edit Menu-SelectAll, then Cell Menu-ConvertToStandardForm)\nIn order \
to convert cells back to StandardForm or to evaluate any parts of the \
unedited notebook, the MCRead package must be loaded first as it contains \
emulation functions and formatting functions as well as conversion."
}], "Text",
  CellTags->"sc1"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            ButtonBox["\<\"Open file in StandardForm\"\>",
              ButtonFunction:>CompoundExpression[ 
                  Needs[ "MCRead`"], 
                  MCRead`MCRead[ 
                    If[ 
                      StringMatchQ[ $Version, "*3.0*"], 
                      Module[ {nb, result}, 
                        CompoundExpression[ 
                          Set[ nb, 
                            NotebookCreate[ 
                            Visible -> False, DefaultNewCellStyle -> 
                              "Text"]], 
                          NotebookWrite[ nb, ""], 
                          FrontEndExecute[ {
                            FrontEnd`FrontEndToken[ nb, "FileNameDialog"]}], 
                          SelectionMove[ nb, All, CellContents], 
                          Set[ result, 
                            NotebookRead[ nb]], 
                          NotebookClose[ nb, Interactive -> False], 
                          ToExpression[ result]]], 
                      CompoundExpression[ 
                        Get[ "Experimental`"], 
                        FileBrowse[ False]]], DisplayForm -> StandardForm]],
              ButtonEvaluator->Automatic,
              Active->True,
              ButtonNote->"Open MathCAD file"]},
          {
            ButtonBox["\<\"Open file in TraditionalForm\"\>",
              ButtonFunction:>CompoundExpression[ 
                  Needs[ "MCRead`"], 
                  MCRead`MCRead[ 
                    If[ 
                      StringMatchQ[ $Version, "*3.0*"], 
                      Module[ {nb, result}, 
                        CompoundExpression[ 
                          Set[ nb, 
                            NotebookCreate[ 
                            Visible -> False, DefaultNewCellStyle -> 
                              "Text"]], 
                          NotebookWrite[ nb, ""], 
                          FrontEndExecute[ {
                            FrontEnd`FrontEndToken[ nb, "FileNameDialog"]}], 
                          SelectionMove[ nb, All, CellContents], 
                          Set[ result, 
                            NotebookRead[ nb]], 
                          NotebookClose[ nb, Interactive -> False], 
                          ToExpression[ result]]], 
                      CompoundExpression[ 
                        Get[ "Experimental`"], 
                        FileBrowse[ False]]], DisplayForm -> 
                    TraditionalForm]],
              ButtonEvaluator->Automatic,
              Active->True,
              ButtonNote->"Open MathCAD file"]}
          },
        RowSpacings->0.2,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left},
        RowsEqual->True],
      (TableForm[ #]&)]], "Input",
  CellTags->"sc1"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Functionality of the converter", "Section",
  CellTags->"sc2"],

Cell[TextData[{
  "The package converts a MathCAD 6 document into a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.0 notebook. While this is intended primarily to convert the content and \
not the evaluation of MathCAD documents, some simple operations may run \
unchanged in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"sc2"],

Cell[TextData[{
  "The aim is to create a document that is as visually close as possible to \
the original document, deviating from this only when it is not possible or \
when the result is easier to convert into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " syntax by making changes.\nSome of the fundamental design decisions \
behind ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and MathCAD are very different. For this reason the document cannot be \
made to look and behave exactly as in its original MathCAD form."
}], "Text",
  CellTags->"sc2"],

Cell[CellGroupData[{

Cell["Appearance of converted notebooks", "Subsection",
  CellTags->"sc2"],

Cell[CellGroupData[{

Cell["Order", "Subsubsection",
  CellTags->"sc2"],

Cell["\<\
MathCAD documents have no linear structure. Elements are placed at any point \
in the document. They do have a linear evaluation order (left to right across \
the page and top to bottom). In converting to notebooks, the elements of the \
MathCAD document are ordered according to their evaluation order. Global \
definitions are placed at the top of the notebook.\
\>", "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Results", "Subsubsection",
  CellTags->"sc2"],

Cell["\<\
The results of calculations are not stored in the MathCAD document file but \
are recalculated when the document is opened. Consequently no results will be \
present in the notebook. Results, including plots and generated diagrams will \
need to be recalculated where possible.\
\>", "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Function names", "Subsubsection",
  CellTags->"sc2"],

Cell[TextData[{
  "Some attempt is made to convert MathCAD function names to an equivalent or \
similar ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function. This is intended to make it easier to edit your documents into \
a form appropriate for evaluation by ",
  StyleBox["Mathematica.",
    FontSlant->"Italic"],
  " It is not expected to produce \"ready to evaluate\" expressions. However \
for many simple functions, (such as ",
  StyleBox["sin()",
    FontFamily->"Courier"],
  " being replaced by ",
  StyleBox["Sin[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "), this will produce usable input."
}], "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{

Cell["TraditionalForm", "Subsubsection",
  CellTags->"sc2"],

Cell[TextData[{
  "Typeset cells are returned in StandardForm by default. Additional \
TraditionalForm notation rules have been added to support MathCAD notations. \
If you wish to wish to make use of these, you can convert the cells to \
TraditionalForm or use ",
  StyleBox["MCRead[path,OutputForm->TraditionalForm]",
    FontFamily->"Courier"],
  ".  \nEditing the notebooks in TraditionalForm is not advised."
}], "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Limitations", "Subsubsection",
  CellTags->"sc2"],

Cell["\<\
No font family information is retained.
No color information is retained.
No pasted pictures are retained.
Hyperlinks become inert.\
\>", "Text",
  CellTags->"sc2"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Evaluation", "Subsection",
  CellTags->"sc2"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does not use \"automatic evaluation\" to update results. Thus, in order \
to evaluate an expression, it is necessary to evaluate earlier expressions in \
the notebook. Document level definitions are placed in a cell labelled \
\"Document level definitions\" at the top of the notebook.\nSome new \
functions have been created that behave in similar ways to MathCAD functions. \
These allow some basic operations such as list construction and plotting to \
be performed using the original MathCAD notation.\n",
  StyleBox[
  "If you wish to work with the resulting notebook it is highly recommended \
that you remove these functions and use the equivalent standard ",
    FontWeight->"Bold"],
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" functions. The behavior of the equivalent standard ",
    FontWeight->"Bold"],
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[
  " functions is different than the MathCAD functionality but is more \
consistent and more powerful.",
    FontWeight->"Bold"]
}], "Text",
  CellTags->"sc2"],

Cell[CellGroupData[{

Cell["MCRange and MCEvaluate", "Subsubsection",
  CellTags->"sc2"],

Cell[TextData[{
  "MathCAD uses the paradigm of the range variable that is, in a sense, a \
delayed iterator. ",
  StyleBox["MCRange",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an object which is expanded by the function ",
  StyleBox["MCEvaluate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". All requests for output in the MathCAD document (denoted by = ) are \
wrapped in ",
  StyleBox["MCEvaluate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the resulting notebook. This takes care of any range variable \
expansion and automatic unit conversion. ",
  StyleBox["MCEvaluate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is invisible in TraditionalForm. ",
  StyleBox["MCRange",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has a TraditionalForm of (",
  StyleBox["a..b",
    FontFamily->"Courier"],
  ") in the same notation as MathCAD."
}], "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{

Cell["MCPart, MCPartSet", "Subsubsection",
  CellTags->"sc2"],

Cell[TextData[{
  "Part specification in MathCAD depends on the value of the ",
  StyleBox["ORIGIN",
    FontFamily->"Courier"],
  " variable (mapped to ",
  StyleBox["MCOrigin",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "). Setting parts of vectors or matrices automatically pads undefined \
elements with 0. These features are emulated using ",
  StyleBox["MCPart",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["MCPartSet",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Their notation, in TraditionalForm, is the same as the original MathCAD \
document."
}], "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{

Cell["MCRangePlot", "Subsubsection",
  CellTags->"sc2"],

Cell["The standard MathCAD plotting feature is emulated", "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{

Cell["MCMatrixPlot", "Subsubsection",
  CellTags->"sc2"],

Cell["\<\
The standard visualization features for matrices are emulated\
\>", "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{

Cell["MCMagnitude", "Subsubsection",
  CellTags->"sc2"],

Cell[TextData[{
  "MathCAD uses the same notation",
  StyleBox[" |x|",
    FontFamily->"Courier"],
  " for ",
  StyleBox["Abs",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", vector length and ",
  StyleBox["Det",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["MCMagnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " attempts to distinguish between these according to the ",
  StyleBox["TensorRank",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " of the argument. It has a TraditionalForm representation of ",
  StyleBox[" |x|",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{

Cell["MCVectorSum", "Subsubsection",
  CellTags->"sc2"],

Cell["A basic summation function", "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{

Cell["MCInverse", "Subsubsection",
  CellTags->"sc2"],

Cell[TextData[{
  "MathCAD uses the same notation for ",
  StyleBox["1/x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Inverse[x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". MCInverse emulates this behavior."
}], "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Limitations", "Subsubsection",
  CellTags->"sc2"],

Cell[BoxData[{
    FormBox[
      RowBox[{"\n", 
        RowBox[{
          RowBox[{
          "MathCAD", " ", "often", " ", "uses", " ", "recursive", " ", 
            "vector", " ", "definitions", " ", "of", " ", "the", " ", "form", 
            "  ", 
            RowBox[{"(", GridBox[{
                  {
                    SubscriptBox[
                      StyleBox["a",
                        FontSlant->"Italic"], \(n + 1\)]},
                  {
                    SubscriptBox[
                      StyleBox["b",
                        FontSlant->"Italic"], \(n + 1\)]}
                  }], ")"}]}], ":=", 
          RowBox[{"(", GridBox[{
                {
                  SubscriptBox[
                    StyleBox["b",
                      FontSlant->"Italic"], "n"]},
                {
                  SubscriptBox[
                    StyleBox["a",
                      FontSlant->"Italic"], "n"]}
                }], ")"}]}], "  "}], TextForm], 
    FormBox[
      RowBox[{"\t\t", 
        \(visual\ translation\ of\ these\ is\ supported\ but\ evaluation\ is\ 
          \(not . \)\)}], TextForm]}], "Text",
  CellTags->"sc2"],

Cell[TextData[{
  "Linked or included document definitions are lost.\nDocument level \
definitions, such as change of base units, are discarded except for ORIGIN \
and FRAME.\nMany option settings for details of plot appearance and output \
format are not supported..\nMultiple arguments for matrix plotting are not \
supported.\nSome ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " commands will not evaluate data which contains units. A function ",
  StyleBox["DropUnits[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["expr",
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "can be used to remove unit information from an expression."
}], "Text",
  CellTags->"sc2"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Command name translation", "Section",
  CellTags->"sc3"],

Cell["\<\
Following is a table of command name translations and some comments on the \
success of the translation.\
\>", "Text",
  CellTags->"sc3"],

Cell[BoxData[
    FormBox[
      RowBox[{" ", GridBox[{
            {\(MathCAD\ command\), \(Mathematica\ translation\), "Notes"},
            {"\[CapitalPhi]", 
              StyleBox["UnitStep",
                FontFamily->"Courier"], " "},
            {"acos", 
              StyleBox["ArcCos",
                FontFamily->"Courier"], " "},
            {"acosh", 
              StyleBox["ArcCosh",
                FontFamily->"Courier"], " "},
            {"angle", 
              StyleBox["MCAngle",
                FontFamily->"Courier"], 
              RowBox[{"Needs", " ", 
                StyleBox["MCRead",
                  FontFamily->"Courier"], "  ", "to", " ", "be", " ", 
                \(installed . \)}]},
            {"APPEND", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"APPENDPRN", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"arg", 
              StyleBox["Arg",
                FontFamily->"Courier"], " "},
            {"asin", 
              StyleBox["ArcSin",
                FontFamily->"Courier"], " "},
            {"asinh", 
              StyleBox["ArcSinh",
                FontFamily->"Courier"], " "},
            {"atan", 
              StyleBox["ArcTan",
                FontFamily->"Courier"], " "},
            {"atanh", 
              StyleBox["ArcTanh",
                FontFamily->"Courier"], " "},
            {"augment", 
              StyleBox["RowJoin",
                FontFamily->"Courier"], 
              RowBox[{" ", 
                RowBox[{
                  RowBox[{"This", " ", "requires", " ", "the", " ", 
                    StyleBox[
                      RowBox[{
                        StyleBox["Statistics",
                          FontFamily->"Courier"], 
                        StyleBox["`",
                          "MB",
                          FontFamily->"Courier"], 
                        StyleBox["Master",
                          FontFamily->"Courier"], 
                        StyleBox["`",
                          "MB",
                          FontFamily->"Courier"]}]]}], "\n", "\t", 
                  \(package\ to\ be\ installed\)}]}]},
            {"bulstoer", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"Bulstoer", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"bvalfit", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"C", 
              StyleBox["\[GothicCapitalC]",
                FontFamily->"Courier"], 
              RowBox[{
                StyleBox["C",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], " ", "is", " ", "a", " ", "reserved", 
                " ", "name", " ", "in", " ", "Mathematica", " ", "so", "\n", 
                "\t", "it", " ", "is", " ", "translated", " ", "to", " ", 
                "\[GothicCapitalC]", " ", "to", " ", "avoid", " ", 
                "conflicts"}]},
            {"ceil", 
              StyleBox["Ceiling",
                FontFamily->"Courier"], " "},
            {"cfft", 
              StyleBox["Fourier",
                FontFamily->"Courier"], 
              RowBox[{" ", 
                RowBox[{
                \(cfft, \ CFFT, \ fft\ and\ FFT\ are\ all\ translated\), 
                  "\n", "\t ", 
                  RowBox[{
                    RowBox[{"to", " ", 
                      StyleBox["Fourier",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], ",", " ", 
                    \(though\ they\ use\ a\ variety\ of\ \n\tdifferent\ 
                      conventions\ in\ MathCAD . \ \n\tCare\ should\ be\ taken
                      \ over\ \ the\ required\ \n\t
                      \(conventions . \)\)}]}]}]},
            {"cholesky", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"CFFT", 
              StyleBox["Fourier",
                FontFamily->"Courier"], 
              RowBox[{
              \(cfft, \ CFFT, \ fft\ and\ FFT\ are\ all\ translated\), "\n", 
                "\t ", 
                RowBox[{
                  RowBox[{"to", " ", 
                    StyleBox["Fourier",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], ",", " ", 
                  \(though\ they\ use\ a\ variety\ of\ \n\tdifferent\ 
                    conventions\ in\ MathCAD . \ \n\tCare\ should\ be\ taken\ 
                    over\ \ the\ required\ \n\t\(conventions . \)\)}]}]},
            {\(cnorm \((x)\)\), 
              StyleBox[\(CDF[NormalDistribution[0, 1], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(cols \((x)\)\), 
              StyleBox[\(Last[Dimensions[x]]\),
                FontFamily->"Courier"], " "},
            {"cond1", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"cond2", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"conde", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"corr", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"cvar", 
              StyleBox["Covariance",
                FontFamily->"Courier"], 
              RowBox[{" ", 
                RowBox[{
                  RowBox[{"This", " ", "requires", " ", "the", " ", 
                    StyleBox[
                      RowBox[{
                        StyleBox["Statistics",
                          FontFamily->"Courier"], 
                        StyleBox["`",
                          "MB",
                          FontFamily->"Courier"], 
                        StyleBox["Master",
                          FontFamily->"Courier"], 
                        StyleBox["`",
                          "MB",
                          FontFamily->"Courier"]}]]}], 
                  StyleBox[" ",
                    "MB"], "\n", "\t", \(package\ to\ be\ installed\)}]}]},
            {"cos", 
              StyleBox["Cos",
                FontFamily->"Courier"], " "},
            {"cosh", 
              StyleBox["Cosh",
                FontFamily->"Courier"], " "},
            {"cot", 
              StyleBox["Cot",
                FontFamily->"Courier"], " "},
            {"coth", 
              StyleBox["Coth",
                FontFamily->"Courier"], " "},
            {"csc", 
              StyleBox["Csc",
                FontFamily->"Courier"], " "},
            {"csch", 
              StyleBox["Csch",
                FontFamily->"Courier"], " "},
            {"csort", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"cspline", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"cvar", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {\(dbeta \((x, s1, s2)\)\), 
              StyleBox[\(PDF[BetaDistribution[s1, s2], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(dbinom \((x, sz, pr)\)\), 
              StyleBox[\(PDF[BinomialDistribution[sz, pr], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(dchisq \((x, df)\)\), 
              StyleBox[\(PDF[ChiSquareDistribution[df], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {"\[Delta]", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {\(dexp \((x, r)\)\), 
              StyleBox[\(PDF[ExponentialDistribution[r], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(dF \((x, s1, s2)\)\), 
              StyleBox[\(PDF[FRatioDistribution[s1, s2], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(dgamma \((x, a)\)\), 
              StyleBox[\(PDF[GammaDistribution[a, 1], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(dgeom \((x, p)\)\), 
              StyleBox[\(PDF[GeometricDistribution[p], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(dlnorm \((x, m, sd)\)\), 
              StyleBox[\(PDF[LogNormalDistribution[m, sd], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(dlogis \((x, l, s)\)\), 
              StyleBox[\(PDF[LogisticDistribution[l, s], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(dnbinom \((x, n, p)\)\), 
              StyleBox[\(PDF[NegativeBinomialDistribution[n, p], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(dnorm \((x, n, p)\)\), 
              StyleBox[\(PDF[NormalDistribution[n, p], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(dpois \((x, l)\)\), 
              StyleBox[\(PDF[PoissonDistribution[l], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(dt \((x, l)\)\), 
              StyleBox[\(PDF[StudentTDistribution[l], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(dunif \((x, min, max)\)\), 
              StyleBox[\(PDF[UniformDistribution[min, max], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {"dweibull", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {\(pbinom \((x, sz, pr)\)\), 
              StyleBox[\(CDF[BinomialDistribution[sz, pr], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(pchisq \((x, df)\)\), 
              StyleBox[\(CDF[ChiSquareDistribution[df], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(pexp \((x, r)\)\), 
              StyleBox[\(CDF[ExponentialDistribution[r], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(pF \((x, s1, s2)\)\), 
              StyleBox[\(CDF[FRatioDistribution[s1, s2], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(pgamma \((x, a)\)\), 
              StyleBox[\(CDF[GammaDistribution[a, 1], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(pgeom \((x, p)\)\), 
              StyleBox[\(CDF[GeometricDistribution[p], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(plnorm \((x, m, sd)\)\), 
              StyleBox[\(CDF[LogNormalDistribution[m, sd], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(plogis \((x, l, s)\)\), 
              StyleBox[\(CDF[LogisticDistribution[l, s], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(pnbinom \((x, n, p)\)\), 
              StyleBox[\(CDF[NegativeBinomialDistribution[n, p], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(pnorm \((x, n, p)\)\), 
              StyleBox[\(CDF[NormalDistribution[n, p], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(ppois \((x, l)\)\), 
              StyleBox[\(CDF[PoissonDistribution[l], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(pt \((x, l)\)\), 
              StyleBox[\(CDF[StudentTDistribution[l], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(punif \((x, min, max)\)\), 
              StyleBox[\(CDF[UniformDistribution[min, max], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(qbinom \((x, sz, pr)\)\), 
              StyleBox[\(Quantile[BinomialDistribution[sz, pr], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(qchisq \((x, df)\)\), 
              StyleBox[\(Quantile[ChiSquareDistribution[df], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(qexp \((x, r)\)\), 
              StyleBox[\(Quantile[ExponentialDistribution[r], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(qF \((x, s1, s2)\)\), 
              StyleBox[\(Quantile[FRatioDistribution[s1, s2], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(qgamma \((x, a)\)\), 
              StyleBox[\(Quantile[GammaDistribution[a, 1], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(qgeom \((x, p)\)\), 
              StyleBox[\(Quantile[GeometricDistribution[p], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(qlnorm \((x, m, sd)\)\), 
              StyleBox[\(Quantile[LogNormalDistribution[m, sd], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(qlogis \((x, l, s)\)\), 
              StyleBox[\(Quantile[LogisticDistribution[l, s], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(qnbinom \((x, n, p)\)\), 
              StyleBox[\(Quantile[NegativeBinomialDistribution[n, p], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(qnorm \((x, n, p)\)\), 
              StyleBox[\(Quantile[NormalDistribution[n, p], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(qpois \((x, l)\)\), 
              StyleBox[\(Quantile[PoissonDistribution[l], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(qt \((x, l)\)\), 
              StyleBox[\(Quantile[StudentTDistribution[l], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(qunif \((x, min, max)\)\), 
              StyleBox[\(Quantile[UniformDistribution[min, max], x]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(rbinom \((x, sz, pr)\)\), 
              StyleBox[\(Table[Random[BinomialDistribution[sz, pr]], {x}]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(rchisq \((x, df)\)\), 
              StyleBox[\(Table[Random[ChiSquareDistribution[df]], {x}]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(rexp \((x, r)\)\), 
              StyleBox[\(Table[Random[ExponentialDistribution[r]], {x}]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(rF \((x, s1, s2)\)\), 
              StyleBox[\(Table[Random[FRatioDistribution[s1, s2]], {x}]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(rgamma \((x, a)\)\), 
              StyleBox[\(Table[Random[GammaDistribution[a, 1]], {x}]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(rgeom \((x, p)\)\), 
              StyleBox[\(Table[Random[GeometricDistribution[p]], {x}]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(rlnorm \((x, m, sd)\)\), 
              StyleBox[\(Table[Random[LogNormalDistribution[m, sd]], {x}]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(rlogis \((x, l, s)\)\), 
              StyleBox[\(Random[LogisticDistribution[l, s], {x}]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(rnbinom \((x, n, p)\)\), 
              
              StyleBox[
                \(Table[Random[NegativeBinomialDistribution[n, p]], {x}]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(rnorm \((x, n, p)\)\), 
              StyleBox[\(Table[Random[NormalDistribution[n, p]], {x}]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(rpois \((x, l)\)\), 
              StyleBox[\(Table[Random[PoissonDistribution[l]], {x}]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(rt \((x, l)\)\), 
              StyleBox[\(Table[Random[StudentTDistribution[l]], {x}]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {\(runif \((x, min, max)\)\), 
              StyleBox[\(Table[Random[UniformDistribution[min, max]], {x}]\),
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {"D", 
              StyleBox["\[GothicCapitalD]",
                FontFamily->"Courier"], 
              RowBox[{
                StyleBox["D",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], " ", "is", " ", "a", " ", "reserved", 
                " ", "name", " ", "in", " ", "Mathematica", " ", "so", "\n", 
                "\t", "it", " ", "is", " ", "translated", " ", "to", " ", 
                "\[GothicCapitalD]", "  ", "to", " ", "avoid", " ", 
                "conflicts"}]},
            {"diag", 
              StyleBox["DiagonalMatrix",
                FontFamily->"Courier"], " "},
            {"eigenvals", 
              StyleBox["Eigenvalues",
                FontFamily->"Courier"], " "},
            {"eigenvec", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"eigenvecs", 
              StyleBox["Eigenvectors",
                FontFamily->"Courier"], " "},
            {"\[Epsilon]", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"erf", 
              StyleBox["Erf",
                FontFamily->"Courier"], " "},
            {"exp", 
              StyleBox["Exp",
                FontFamily->"Courier"], " "},
            {"fft", 
              StyleBox["Fourier",
                FontFamily->"Courier"], 
              RowBox[{
              \(cfft, \ CFFT, \ fft\ and\ FFT\ are\ all\ translated\), "\n", 
                "\t ", 
                RowBox[{
                  RowBox[{"to", " ", 
                    StyleBox["Fourier",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], ",", " ", 
                  \(though\ they\ use\ a\ variety\ of\ \n\tdifferent\ 
                    conventions\ in\ MathCAD . \ \n\tCare\ should\ be\ taken\ 
                    over\ \ the\ required\ \n\t\(conventions . \)\)}]}]},
            {"FFT", 
              StyleBox["Fourier",
                FontFamily->"Courier"], 
              RowBox[{
              \(cfft, \ CFFT, \ fft\ and\ FFT\ are\ all\ translated\), "\n", 
                "\t ", 
                RowBox[{
                  RowBox[{"to", " ", 
                    StyleBox["Fourier",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], ",", " ", 
                  \(though\ they\ use\ a\ variety\ of\ \n\tdifferent\ 
                    conventions\ in\ MathCAD . \ \n\tCare\ should\ be\ taken\ 
                    over\ \ the\ required\ \n\t\(conventions . \)\)}]}]},
            {"find", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"floor", 
              StyleBox["Floor",
                FontFamily->"Courier"], " "},
            {"\[CapitalGamma]", 
              StyleBox["Gamma",
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"FRAME", 
              StyleBox["MCFrame",
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{
                  RowBox[{
                  "This", " ", "is", " ", "the", " ", "MathCAD", " ", 
                    "animation", " ", \(variable . \n\tAnimations\), " ", 
                    "are", " ", "performed", " ", "in", " ", "a", " ", 
                    "different", "\n", "\t", "way", " ", "in", " ", 
                    \(Mathematica . \ Generally\), " ", 
                    RowBox[{
                      StyleBox["Table",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], "\n", "\t", 
                      RowBox[{"expr", ",", 
                        RowBox[{
                          StyleBox["{",
                            FontFamily->"Courier",
                            FontWeight->"Bold"], 
                          RowBox[{
                            StyleBox["MCFrame",
                              FontFamily->"Courier",
                              FontWeight->"Bold"], ",", "start", ",", 
                            "end"}], 
                          StyleBox["}",
                            FontFamily->"Courier",
                            FontWeight->"Bold"]}]}], 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], " ", "will", " ", "do", " ", 
                    "this", "\n", "\t", "but", " ", "expr", " ", "may", " ", 
                    "be", " ", "the", " ", "whole", " ", "notebook", " ", 
                    "or"}], " ", "\n", "\t", 
                  RowBox[{"just", " ", "the", " ", 
                    StyleBox["Plot",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], " ", \(command . \)}]}], " "}]},
            {"genfit", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"geninv", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"genvals", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"hist", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"identity", 
              StyleBox["IdentityMatrix",
                FontFamily->"Courier"], " "},
            {"if", 
              StyleBox["If",
                FontFamily->"Courier"], 
              RowBox[{
              \(All\ boolian\ operations\ are\ numeric\ in\ \n\t
                    MathCAD . \ Eg\ 7 > 3\ returns\ 1\), ",", " ", 
                RowBox[{"3", ">", 
                  RowBox[{
                  "7", "\n", "\t", "returns", " ", "0.", " ", "The", " ", 
                    "test", " ", \(for\ '\), \(if'\), " ", "in", " ", 
                    "MathCAD", "\n", "\t", "expects", " ", "a", " ", "1", 
                    " ", "or", " ", "0", " ", "while", " ", "in", " ", 
                    "Mathematica", " ", "If", " ", "\n", "\t", "expects", 
                    " ", "True", " ", "or", " ", \(False . \ So\), " ", 
                    "for", " ", "example", " ", "\n", "\t", "if", 
                    RowBox[{"(", 
                      RowBox[{
                      \(5 > 3.  .. \), " ", "will", " ", "translate", " ", 
                        "well", " ", "but", " ", "\n", "\t", "if", 
                        RowBox[{"(", 
                          RowBox[{
                          \(\((5 > 3)\)*\((2 < 1)\) ... \), "will", " ", 
                            "not", " ", "since", "\n", "\t", 
                            StyleBox["True",
                              FontFamily->"Courier",
                              FontWeight->"Bold"], 
                            StyleBox["*",
                              FontFamily->"Courier",
                              FontWeight->"Bold"], 
                            StyleBox["False",
                              FontFamily->"Courier",
                              FontWeight->"Bold"], " ", "will", " ", "not", 
                            " ", "be", " ", "evaluated", " ", "in", " ", 
                            "\n", "\t", \(Mathematica . \)}]}]}]}]}]}]}]},
            {\(interp \((s, x, y, var)\)\), 
              StyleBox[\(\(Interpolation[Transpose[{x, y}]]\)[var]\),
                FontFamily->"Courier"], \(\ 
              MathCADs\ interp\ command\ works\n\tvery\ differently\ than\ 
                Mathematica\n\tsince\ it\ needs\ a\ vector\ of\ derivative\n\t
                values\ \((s)\) . \ This\ parameter\ is\ \n\tdiscarded\ in\ 
                the\ \(translation . \)\)},
            {\(IO \((x)\)\), 
              StyleBox[\(BesselI[0, x]\),
                FontFamily->"Courier"], " "},
            {\(I1 \((x)\)\), 
              StyleBox[\(BesselI[1, x]\),
                FontFamily->"Courier"], " "},
            {"In", 
              StyleBox["BesselI",
                FontFamily->"Courier"], " "},
            {"Im", 
              StyleBox["Im",
                FontFamily->"Courier"], 
              \(Already\ in\ Mathematica\ syntax\)},
            {"intercept", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"interp", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"iwave", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"icfft", 
              StyleBox["InverseFourier",
                FontFamily->"Courier"], 
              RowBox[{"   ", 
                RowBox[{
                \(ICFFT\ and\ \ icfft\ are\ translated\ to\), " ", "\n", 
                  "\t", 
                  RowBox[{
                    StyleBox["InverseFourier",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], ",", " ", 
                    \(though\ they\ use\ \ \n\tdifferent\ conventions\ in\ 
                      MathCAD . \ \n\tCare\ should\ be\ taken\ over\ \ the\ 
                      required\ \n\t\(conventions . \)\)}]}]}]},
            {"ICFFT", 
              StyleBox["InverseFourier",
                FontFamily->"Courier"], 
              RowBox[{"  ", 
                RowBox[{
                \(ICFFT\ and\ \ icfft\ are\ translated\ to\), " ", "\n", 
                  "\t", 
                  RowBox[{
                    StyleBox["InverseFourier",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], ",", " ", 
                    \(though\ they\ use\ \ \n\tdifferent\ conventions\ in\ 
                      MathCAD . \ \n\tCare\ should\ be\ taken\ over\ \ the\ 
                      required\ \n\t\(conventions . \)\)}]}]}]},
            {\(J0 \((x)\)\), 
              StyleBox[\(BesselJ[0, x]\),
                FontFamily->"Courier"], " "},
            {\(J1 \((x)\)\), 
              StyleBox[\(BesselJ[1, x]\),
                FontFamily->"Courier"], " "},
            {"Jn", 
              StyleBox["BesselJ",
                FontFamily->"Courier"], " "},
            {\(K0 \((x)\)\), 
              StyleBox[\(BesselK[0, x]\),
                FontFamily->"Courier"], " "},
            {\(K1 \((x)\)\), 
              StyleBox[\(BesselK[1, x]\),
                FontFamily->"Courier"], " "},
            {"Kn", 
              StyleBox["BesselK",
                FontFamily->"Courier"], " "},
            {"ksmooth", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {\(last \((x)\)\), 
              StyleBox[\(Length[x] - 1 + MCOrigin\),
                FontFamily->"Courier"], 
              RowBox[{
              \(The\ index\ value\ of\ lists\ depends\ on\ the\ \n\tvalue\ of
                  \ the\ origin\ variable\ in\ MathCAD . \n\tThis\ awkwardness
                  \ is\ handled\ by\), " ", "\n", "\t", 
                RowBox[{"commands", " ", "like", " ", 
                  RowBox[{
                    StyleBox["MCPart",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], ".", " ", "Here"}], " ", 
                  StyleBox["MCOrigin",
                    FontFamily->"Courier",
                    FontWeight->"Bold"]}], "\n", "\t", 
                \(is\ refered\ to\ directly . \ In\ default\ usage\), "\n", 
                "\t", 
                RowBox[{
                  StyleBox["MCOrigin",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], " ", "will", " ", "have", " ", 
                  "the", " ", "value", " ", "1."}]}]},
            {"length", 
              StyleBox["Length",
                FontFamily->"Courier"], " "},
            {"linfit", 
              StyleBox["Fit",
                FontFamily->"Courier"], 
              \(This\ convention\ and\ syntax\ for\ linfit\ is\ so\ \n\tfar\ 
                removed\ from\ Mathematica\ that\ it\ is\ \n\tunlikely\ that\ 
                direct\ translation\ is\ \n\tpossible . \ Translation\ here\ 
                is\ only\ a\ \n\t\(guide . \)\)},
            {\(linterp \((x, y, var)\)\), 
              StyleBox[\(Interpolation[Transpose[{x, y}], var]\),
                FontFamily->"Courier"], " "},
            {"ln", 
              StyleBox["Log",
                FontFamily->"Courier"], " "},
            {"loess", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {\(log \((x)\)\), 
              StyleBox[\(Log[10, x]\),
                FontFamily->"Courier"], " "},
            {"lsolve", 
              StyleBox["LinearSolve",
                FontFamily->"Courier"], \(\ 
              Linked\ with\ the\ untranslated\ MathCAD\n\tcommand\ ' given'\ 
                so\ cannot\ evaluate\)},
            {"lspline", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"lu", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"min", 
              StyleBox["Min",
                FontFamily->"Courier"], " "},
            {"max", 
              StyleBox["Max",
                FontFamily->"Courier"], " "},
            {"mean", 
              StyleBox["Mean",
                FontFamily->"Courier"], 
              RowBox[{"Needs", " ", 
                StyleBox["Statistics`Master`",
                  FontFamily->"Courier"], " ", "to", " ", "be", " ", 
                "installed"}]},
            {"median", 
              StyleBox["Median",
                FontFamily->"Courier"], 
              RowBox[{"Needs", " ", 
                StyleBox["Statistics`Master`",
                  FontFamily->"Courier"], " ", "to", " ", "be", " ", 
                "installed"}]},
            {"medsmooth", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"minerr", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], \(\ 
              Linked\ with\ the\ untranslated\ MathCAD\n\tcommand\ ' given'\ 
                so\ cannot\ evaluate\)},
            {"mod", 
              StyleBox["Mod",
                FontFamily->"Courier"], " "},
            {\(matrix \((n, m, fn)\)\), 
              StyleBox[\(Array[fn, {n, m}]\),
                FontFamily->"Courier"], " "},
            {"multigrid", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"N", 
              StyleBox["\[GothicCapitalN]",
                FontFamily->"Courier"], 
              RowBox[{
                StyleBox["N",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], " ", "is", " ", "a", " ", "reserved", 
                " ", "name", " ", "in", " ", "Mathematica", " ", "so", "\n", 
                "\t", "it", " ", "is", " ", "translated", " ", "to", " ", 
                "\[GothicCapitalN]", " ", "to", " ", "avoid", " ", 
                "conflicts"}]},
            {"norm1", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"norm2", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"norme", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"normi", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"ORIGIN", 
              StyleBox["MCOrigin",
                FontFamily->"Courier"], 
              RowBox[{
              \(The\ index\ value\ of\ lists\ depends\ on\ the\ \n\tvalue\ of
                  \ the\ origin\ variable\ in\ MathCAD . \n\tThis\ awkwardness
                  \ is\ handled\ by\), " ", "\n", "\t", 
                RowBox[{"commands", " ", "like", " ", 
                  RowBox[{
                    StyleBox["MCPart",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "."}]}]}]},
            {"\[Phi]", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"polyroots", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"predict", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"pspline", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"pt", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"qr", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"qt", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"rank", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"re", 
              StyleBox["Re",
                FontFamily->"Courier"], " "},
            {"READ", 
              StyleBox[\(Note\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"READBMP", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"READPRN", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"READRGB", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"regress", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"relax", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"reverse", 
              StyleBox["Reverse",
                FontFamily->"Courier"], " "},
            {"rkadapt", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"Rkadapt", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"rkfixed", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {\(rnd \((x)\)\), 
              StyleBox[\(Random[]*\ x\),
                FontFamily->"Courier"], " "},
            {"root", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"rows", 
              StyleBox["Length",
                FontFamily->"Courier"], " "},
            {"rref", 
              StyleBox["RowReduce",
                FontFamily->"Courier"], " "},
            {"rsort", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"rt", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"rweibull", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"sbval", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"sec", 
              StyleBox["Sec",
                FontFamily->"Courier"], " "},
            {"sech", 
              StyleBox["Sech",
                FontFamily->"Courier"], " "},
            {"sin", 
              StyleBox["Sin",
                FontFamily->"Courier"], " "},
            {"sinh", 
              StyleBox["Sinh",
                FontFamily->"Courier"], " "},
            {\(slope \((x, y)\)\), 
              StyleBox[\(MCSlope[x, y]\),
                FontFamily->"Courier"], 
              \(This\ is\ not\ a\ standard\ Mathematica\n\tcommand . \ It\ is
                \ defined\ within\ the\ \n\tconverter\ \(package . \)\)},
            {\(intercept \((x, y)\)\), 
              StyleBox[\(MCIntercept[x, y]\),
                FontFamily->"Courier"], 
              \(This\ is\ not\ a\ standard\ Mathematica\n\tcommand . \ It\ is
                \ defined\ within\ the\ \n\tconverter\ \(package . \)\)},
            {"sort", 
              StyleBox["Sort",
                FontFamily->"Courier"], " "},
            {"stack", 
              StyleBox["ColumnJoin",
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {"stdev", 
              StyleBox["StandardDeviation",
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{"This", " ", "requires", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["Statistics",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"], 
                      StyleBox["Master",
                        FontFamily->"Courier"], 
                      StyleBox["`",
                        "MB",
                        FontFamily->"Courier"]}]]}], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {"stiffb", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"Stiffb", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"stiffr", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"Stiffr", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"submatrix", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"supsmooth", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"svd", 
              StyleBox["SingularValues",
                FontFamily->"Courier"], 
              \(This\ command\ is\ translated\ as\ a\ guide\n\tonly . \ It\ 
                will\ not\ \(evaluate . \)\)},
            {"svds", 
              StyleBox["SingularValues",
                FontFamily->"Courier"], 
              \(This\ command\ is\ translated\ as\ a\ guide\n\tonly . \ It\ 
                will\ not\ \(evaluate . \)\)},
            {"tan", 
              StyleBox["Tan",
                FontFamily->"Courier"], " "},
            {"tanh", 
              StyleBox["Tanh",
                FontFamily->"Courier"], " "},
            {"tr", 
              StyleBox["Tr",
                FontFamily->"Courier"], " "},
            {"until", 
              StyleBox["Until",
                FontFamily->"Courier"], 
              RowBox[{
                RowBox[{
                \(All\ boolian\ operations\ are\ numeric\ in\ \n\t
                      MathCAD . \ Eg\ 7 > 3\ returns\ 1, \ 
                  3 > 7\n\treturns\ 0. \ The\ test\ for\ ' until'\ in\ \n\t
                      MathCAD\ expects\ a\ 1\ or\ 0\ while\ in\ \n\t
                      Mathematica\ If\), " ", "\n", "\t", 
                  RowBox[{"expects", " ", 
                    StyleBox["True",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], " ", "or", " ", 
                    RowBox[{
                      StyleBox["False",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], "."}]}]}], " "}]},
            {"var", 
              StyleBox["Variance",
                FontFamily->"Courier"], 
              RowBox[{\(This\ requires\ the\), " ", "\n", "\t", 
                StyleBox[
                  RowBox[{
                    StyleBox["Statistics",
                      FontFamily->"Courier"], 
                    StyleBox["`",
                      "MB",
                      FontFamily->"Courier"], 
                    StyleBox["Master",
                      FontFamily->"Courier"], 
                    StyleBox["`",
                      "MB",
                      FontFamily->"Courier"]}]], "\n", "\t", 
                \(package\ to\ be\ installed\)}]},
            {"wave", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"WRITE", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"WRITEBMP", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"WRITEPRN", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {"WRITERGB", 
              StyleBox[\(Not\ translated\),
                FontFamily->"Courier"], 
              \(This\ function\ will\ \ not\ evaluate\)},
            {\(Y0 \((x)\)\), 
              StyleBox[\(BesselY[0, x]\),
                FontFamily->"Courier"], " "},
            {\(Y1 \((x)\)\), 
              StyleBox[\(BesselY[1, x]\),
                FontFamily->"Courier"], " "},
            {"Yn", 
              StyleBox["BesselY",
                FontFamily->"Courier"], " "}
            },
          RowAlignments->Baseline,
          ColumnAlignments->{Left},
          GridFrame->True,
          RowLines->True,
          ColumnLines->True]}], TextForm]], "Text",
  CellTags->"sc3"]
}, Closed]],

Cell[CellGroupData[{

Cell["Versions", "Section",
  CellTags->"sc4"],

Cell["\<\
The package currently handles uncompressed MathCAD 6 and MathCAD 6 Pro \
documents. Documents created in other versions of MathCAD or compressed \
documents should be opened in MathCAD 6 or later and re-saved as MathCAD 6 \
documents before conversion.
It has not been tested on files created by MathCAD for Macintosh\
\>", "Text",
  CellTags->"sc4"]
}, Closed]],

Cell[CellGroupData[{

Cell["Incompatibilities & problems", "Section",
  CellTags->"sc5"],

Cell[TextData[{
  "The package changes the attributes for the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Subscript",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".\n",
    FontWeight->"Bold"],
  "Some additional formatting rules have been added to TraditionalForm.\nFor \
most robust results restart ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " before converting documents."
}], "Text",
  CellTags->"sc5"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1024}, {0, 712}},
WindowSize->{846, 601},
WindowMargins->{{Automatic, 47}, {Automatic, 5}},
StyleDefinitions -> "Textbook.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "sc1"->{
    Cell[1801, 55, 61, 1, 85, "Section",
      CellTags->"sc1"],
    Cell[1887, 60, 108, 2, 37, "Subsubsection",
      CellTags->"sc1"],
    Cell[1998, 64, 54, 1, 25, "Text",
      CellTags->"sc1"],
    Cell[2055, 67, 62, 2, 30, "Input",
      CellTags->"sc1"],
    Cell[2120, 71, 193, 7, 26, "Text",
      CellTags->"sc1"],
    Cell[2316, 80, 88, 2, 30, "Input",
      CellTags->"sc1"],
    Cell[2407, 84, 545, 16, 68, "Text",
      CellTags->"sc1"],
    Cell[2955, 102, 127, 3, 30, "Input",
      CellTags->"sc1"],
    Cell[3085, 107, 792, 16, 151, "Text",
      CellTags->"sc1"],
    Cell[3880, 125, 2863, 64, 54, "Input",
      CellTags->"sc1"]},
  "sc2"->{
    Cell[6792, 195, 68, 1, 53, "Section",
      CellTags->"sc2"],
    Cell[6863, 198, 381, 11, 59, "Text",
      CellTags->"sc2"],
    Cell[7247, 211, 577, 13, 84, "Text",
      CellTags->"sc2"],
    Cell[7849, 228, 74, 1, 40, "Subsection",
      CellTags->"sc2"],
    Cell[7948, 233, 49, 1, 37, "Subsubsection",
      CellTags->"sc2"],
    Cell[8000, 236, 406, 7, 76, "Text",
      CellTags->"sc2"],
    Cell[8443, 248, 51, 1, 31, "Subsubsection",
      CellTags->"sc2"],
    Cell[8497, 251, 320, 6, 59, "Text",
      CellTags->"sc2"],
    Cell[8854, 262, 58, 1, 31, "Subsubsection",
      CellTags->"sc2"],
    Cell[8915, 265, 663, 19, 77, "Text",
      CellTags->"sc2"],
    Cell[9615, 289, 59, 1, 31, "Subsubsection",
      CellTags->"sc2"],
    Cell[9677, 292, 444, 9, 84, "Text",
      CellTags->"sc2"],
    Cell[10158, 306, 55, 1, 31, "Subsubsection",
      CellTags->"sc2"],
    Cell[10216, 309, 174, 6, 100, "Text",
      CellTags->"sc2"],
    Cell[10439, 321, 51, 1, 34, "Subsection",
      CellTags->"sc2"],
    Cell[10493, 324, 1178, 27, 177, "Text",
      CellTags->"sc2"],
    Cell[11696, 355, 66, 1, 37, "Subsubsection",
      CellTags->"sc2"],
    Cell[11765, 358, 939, 29, 97, "Text",
      CellTags->"sc2"],
    Cell[12741, 392, 61, 1, 31, "Subsubsection",
      CellTags->"sc2"],
    Cell[12805, 395, 701, 23, 78, "Text",
      CellTags->"sc2"],
    Cell[13543, 423, 55, 1, 31, "Subsubsection",
      CellTags->"sc2"],
    Cell[13601, 426, 84, 1, 25, "Text",
      CellTags->"sc2"],
    Cell[13722, 432, 56, 1, 31, "Subsubsection",
      CellTags->"sc2"],
    Cell[13781, 435, 104, 3, 25, "Text",
      CellTags->"sc2"],
    Cell[13922, 443, 55, 1, 31, "Subsubsection",
      CellTags->"sc2"],
    Cell[13980, 446, 668, 25, 44, "Text",
      CellTags->"sc2"],
    Cell[14685, 476, 55, 1, 31, "Subsubsection",
      CellTags->"sc2"],
    Cell[14743, 479, 61, 1, 25, "Text",
      CellTags->"sc2"],
    Cell[14841, 485, 53, 1, 31, "Subsubsection",
      CellTags->"sc2"],
    Cell[14897, 488, 285, 11, 26, "Text",
      CellTags->"sc2"],
    Cell[15219, 504, 55, 1, 31, "Subsubsection",
      CellTags->"sc2"],
    Cell[15277, 507, 1156, 32, 75, "Text",
      CellTags->"sc2"],
    Cell[16436, 541, 835, 23, 143, "Text",
      CellTags->"sc2"]},
  "sc3"->{
    Cell[17332, 571, 62, 1, 53, "Section",
      CellTags->"sc3"],
    Cell[17397, 574, 147, 4, 25, "Text",
      CellTags->"sc3"],
    Cell[17547, 580, 78590, 1835, 6327, "Text",
      CellTags->"sc3"]},
  "sc4"->{
    Cell[96174, 2420, 46, 1, 53, "Section",
      CellTags->"sc4"],
    Cell[96223, 2423, 360, 7, 67, "Text",
      CellTags->"sc4"]},
  "sc5"->{
    Cell[96620, 2435, 66, 1, 53, "Section",
      CellTags->"sc5"],
    Cell[96689, 2438, 478, 16, 76, "Text",
      CellTags->"sc5"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"sc1", 97824, 2475},
  {"sc2", 98486, 2496},
  {"sc3", 100760, 2563},
  {"sc4", 100976, 2570},
  {"sc5", 101122, 2575}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 45, 0, 59, "Title"],

Cell[CellGroupData[{
Cell[1801, 55, 61, 1, 85, "Section",
  CellTags->"sc1"],

Cell[CellGroupData[{
Cell[1887, 60, 108, 2, 37, "Subsubsection",
  CellTags->"sc1"],
Cell[1998, 64, 54, 1, 25, "Text",
  CellTags->"sc1"],
Cell[2055, 67, 62, 2, 30, "Input",
  CellTags->"sc1"],
Cell[2120, 71, 193, 7, 26, "Text",
  CellTags->"sc1"],
Cell[2316, 80, 88, 2, 30, "Input",
  CellTags->"sc1"],
Cell[2407, 84, 545, 16, 68, "Text",
  CellTags->"sc1"],
Cell[2955, 102, 127, 3, 30, "Input",
  CellTags->"sc1"],
Cell[3085, 107, 792, 16, 151, "Text",
  CellTags->"sc1"],
Cell[3880, 125, 2863, 64, 54, "Input",
  CellTags->"sc1"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6792, 195, 68, 1, 53, "Section",
  CellTags->"sc2"],
Cell[6863, 198, 381, 11, 59, "Text",
  CellTags->"sc2"],
Cell[7247, 211, 577, 13, 84, "Text",
  CellTags->"sc2"],

Cell[CellGroupData[{
Cell[7849, 228, 74, 1, 40, "Subsection",
  CellTags->"sc2"],

Cell[CellGroupData[{
Cell[7948, 233, 49, 1, 37, "Subsubsection",
  CellTags->"sc2"],
Cell[8000, 236, 406, 7, 76, "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{
Cell[8443, 248, 51, 1, 31, "Subsubsection",
  CellTags->"sc2"],
Cell[8497, 251, 320, 6, 59, "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{
Cell[8854, 262, 58, 1, 31, "Subsubsection",
  CellTags->"sc2"],
Cell[8915, 265, 663, 19, 77, "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{
Cell[9615, 289, 59, 1, 31, "Subsubsection",
  CellTags->"sc2"],
Cell[9677, 292, 444, 9, 84, "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{
Cell[10158, 306, 55, 1, 31, "Subsubsection",
  CellTags->"sc2"],
Cell[10216, 309, 174, 6, 100, "Text",
  CellTags->"sc2"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10439, 321, 51, 1, 34, "Subsection",
  CellTags->"sc2"],
Cell[10493, 324, 1178, 27, 177, "Text",
  CellTags->"sc2"],

Cell[CellGroupData[{
Cell[11696, 355, 66, 1, 37, "Subsubsection",
  CellTags->"sc2"],
Cell[11765, 358, 939, 29, 97, "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{
Cell[12741, 392, 61, 1, 31, "Subsubsection",
  CellTags->"sc2"],
Cell[12805, 395, 701, 23, 78, "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{
Cell[13543, 423, 55, 1, 31, "Subsubsection",
  CellTags->"sc2"],
Cell[13601, 426, 84, 1, 25, "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{
Cell[13722, 432, 56, 1, 31, "Subsubsection",
  CellTags->"sc2"],
Cell[13781, 435, 104, 3, 25, "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{
Cell[13922, 443, 55, 1, 31, "Subsubsection",
  CellTags->"sc2"],
Cell[13980, 446, 668, 25, 44, "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{
Cell[14685, 476, 55, 1, 31, "Subsubsection",
  CellTags->"sc2"],
Cell[14743, 479, 61, 1, 25, "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{
Cell[14841, 485, 53, 1, 31, "Subsubsection",
  CellTags->"sc2"],
Cell[14897, 488, 285, 11, 26, "Text",
  CellTags->"sc2"]
}, Closed]],

Cell[CellGroupData[{
Cell[15219, 504, 55, 1, 31, "Subsubsection",
  CellTags->"sc2"],
Cell[15277, 507, 1156, 32, 75, "Text",
  CellTags->"sc2"],
Cell[16436, 541, 835, 23, 143, "Text",
  CellTags->"sc2"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[17332, 571, 62, 1, 53, "Section",
  CellTags->"sc3"],
Cell[17397, 574, 147, 4, 25, "Text",
  CellTags->"sc3"],
Cell[17547, 580, 78590, 1835, 6327, "Text",
  CellTags->"sc3"]
}, Closed]],

Cell[CellGroupData[{
Cell[96174, 2420, 46, 1, 53, "Section",
  CellTags->"sc4"],
Cell[96223, 2423, 360, 7, 67, "Text",
  CellTags->"sc4"]
}, Closed]],

Cell[CellGroupData[{
Cell[96620, 2435, 66, 1, 53, "Section",
  CellTags->"sc5"],
Cell[96689, 2438, 478, 16, 76, "Text",
  CellTags->"sc5"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

